import {DataPipeStatus} from './DataPipeStatus';
import {DataPipeType} from './DataPipeType';

export declare class DataPipe {
	/**
	 * Gets a unique identifier for the pipe
	 */
	id: string;

	/**
	 * Return label associated with this DataPipe.
	 */
	label: string;

	/**
	 * Gets the identities of the peers attached to this pipe
	 */
	participants: string[];

	/**
	 * Gets the identities of the remote peers attached to this pipe
	 */
	remoteParticipants: string[];

	/**
	 * Retrieves the current status of this pipe.
	 */
	status: DataPipeStatus;

	/**
	 * Gets pipe type
	 */
	type: DataPipeType;

	/**
	 * Adds a participant to this pipe.
	 */
	addParticipant(identity: string): Promise<DataPipe>;

	/**
	 * Attempts to reach the pipe recipient and establish a connection.
	 */
	connect(): Promise<DataPipe>;

	/**
	 * Ends an active pipe.
	 */
	disconnect(): Promise<DataPipe>;

	/**
	 * Called when a user does not wish to accept an incoming pipe.
	 */
	reject(): Promise<DataPipe>;

	/**
	 * Removes a participant from this pipe.
	 */
	removeParticipant(identity: string): Promise<DataPipe>;

	/**
	 * Sends data to the DataPipe recipients
	 */
	send(data: string): Promise<DataPipe>;

	/**
	 * Returns a Promise resolved when pipe reaches provided state
	 */
	when(status: DataPipeStatus): Promise<DataPipe>;

	/**
	 * Attach events to callback functions.
	 */
	on(event: string, callback: (param: any) => void): void;
}
